%%
%   Approximation of the eigenbasis
%


%%
close all
clear all
addpath('Functions/')


%% Parameters
kerType = 'gauss';  % kernel (see getRbf.m)
omega = 'disk';     % domain Omega (see getPoints.m)
mO = pi;            % Leb. measure of Omega
ep = 1;             % shape parameter
m = 10000;          % grid size
n = 30;             % subspace size
tol = 1e-10;        % tolerance for the greedy alg.
nPlot = 10;         % number of basis to show

%% Loading
ker = getRbf(kerType); % radial basis
ker = @(x, y) ker(ep, distanceMatrix(x, y)); % symmetric kernel
[X, m, xx, yy, indPlot, con] = getPoints(omega, m, 'u', 0); % starting grid


%% Newton basis (with std greedy alg. by L_infty maximization)
[V, ind, n] = newton(ker, X, tol, n);


%% Approximation of the eigenbasis 
G = V'*V*(mO/m); % L_2 gramian matrix
[Q, L] = svd(G); % eigenbasis
l = diag(L); % eigenvalues
Vu = V * Q; % eigenbasis (normalized in the native space) evaluated on X
[~, invInd] = sort(ind, 'ascend');
Vu = Vu(invInd, :); % sort the basis according to the greedy selection

%% Plots
for j = 1 : nPlot
    titleString = ['Eigenbasis ' num2str(j)];
    plotSurf(xx, yy, indPlot, con, Vu(:, j), titleString, 1)
    pause(0.5)
end

